{ config, lib, pkgs, modulesPath, inputs, ... }: let
  inherit (inputs) nixos-hardware;
in {
  imports = [
    (modulesPath + "/installer/scan/not-detected.nix")
    nixos-hardware.nixosModules.apple-t2
  ];

  # Nix Config
  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";

  boot.initrd.availableKernelModules = [ "xhci_pci" "nvme" "usbhid" "usb_storage" "sd_mod" "cryptd" ];
  boot.initrd.kernelModules = [ ];
  boot.kernelModules = [ "kvm-intel" ];
  boot.extraModulePackages = [ ];

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  boot.loader.efi.efiSysMountPoint = "/boot";

  # File Systems
  fileSystems."/" = { 
    device = "/dev/disk/by-uuid/e36a3f85-020f-4d6c-844f-b81131ce7e63";
    fsType = "ext4";
  };
  boot.initrd.luks.devices."luks-a226aaf4-1250-447b-a5fc-fa37758d332a".device = "/dev/disk/by-uuid/a226aaf4-1250-447b-a5fc-fa37758d332a";
  fileSystems."/boot" = { 
    device = "/dev/disk/by-uuid/5F66-17ED";
    fsType = "vfat";
    options = [ "fmask=0022" "dmask=0022" ];
  };
  swapDevices = [ { device = "/swapfile"; size = 8 * 1024; } ];

  # Misc
  networking.useDHCP = lib.mkDefault true;

  hardware.bosto-touchpad.enable = true;

  hardware.cpu.intel.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
